@@ -1,5 +1,5 @@
 """Interact with the Censys Search Host API."""
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, Union
 
 from .api import CensysSearchAPIv2
 from censys.common.types import Datetime
@@ -144,6 +144,8 @@ class CensysHosts(CensysSearchAPIv2):
         per_page: int = 100,
         cursor: Optional[str] = None,
         pages: int = 1,
+        fields: Optional[List[str]] = None,
+        sort: Optional[Union[str, List[str]]] = None,
         virtual_hosts: Optional[str] = None,
         **kwargs: Any,
     ) -> CensysSearchAPIv2.Query:
@@ -156,8 +158,10 @@ class CensysHosts(CensysSearchAPIv2):
             query (str): The query to be executed.
             per_page (int): Optional; The number of results to be returned for each page. Defaults to 100.
             cursor (int): Optional; The cursor of the desired result set.
-            virtual_hosts (str): Optional; Whether to include virtual hosts in the results. Valid values are "EXCLUDE", "INCLUDE", and "ONLY".
             pages (int): Optional; The number of pages returned. Defaults to 1.
+            fields (List[str]): Optional; The fields to return. Defaults to all fields.
+            sort (str): Optional; The method used to sort results. Valid values are "RELEVANCE", "DESCENDING", and "ASCENDING".
+            virtual_hosts (str): Optional; Whether to include virtual hosts in the results. Valid values are "EXCLUDE", "INCLUDE", and "ONLY".
             **kwargs (Any): Optional; Additional arguments to be passed to the query.
 
         Returns:
@@ -165,7 +169,7 @@ class CensysHosts(CensysSearchAPIv2):
         """
         if virtual_hosts:
             kwargs["virtual_hosts"] = virtual_hosts
-        return super().search(query, per_page, cursor, pages, **kwargs)
+        return super().search(query, per_page, cursor, pages, fields, sort, **kwargs)
 
     def aggregate(
         self,
